wheel: A built-package format for Python
========================================

Description
-----------

A built-package format for Python

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/wheel/

